@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+ 
 from calculate.lib.cl_progressbar import get_progress_bar, get_message_box
 from calculate.lib.utils.colortext import TextState
 import sys
@@ -49,7 +49,7 @@ class ProgressStateGui(ProgressState):
         self.parent.set_progressbar(None)
 
 
-class ResultViewerDecorator(object):
+class ResultViewerDecorator():
     def __init__(self, rv):
         self.rv = rv
         for v in self.rv.states.values():
@@ -65,7 +65,7 @@ class ProgressGui(ResultViewerDecorator):
     """
 
     def __init__(self, rv):
-        super(ProgressGui, self).__init__(rv)
+        super().__init__(rv)
         self.rv.states['pre-progress'] = PreProgressStateGui(self)
         self.rv.states['progress'] = ProgressStateGui(self)
         self.progress_title = ""
@@ -84,7 +84,7 @@ class ErrorGui(ResultViewerDecorator):
     """
 
     def __init__(self, rv):
-        super(ErrorGui, self).__init__(rv)
+        super().__init__(rv)
         self.messages = []
 
     def show_messages(self):
@@ -108,7 +108,7 @@ class WarningGui(ResultViewerDecorator):
     """
 
     def __init__(self, rv):
-        super(WarningGui, self).__init__(rv)
+        super().__init__(rv)
         self.warnings = []
 
     def show_messages(self):
