@@ -195,12 +195,15 @@ def local_method(metaObject, args, unknown_args):
             _print(_("Method not found for %s") % sym_link)
             sys.exit(1)
 
-    if args.list_methods:
+    if args.list_methods and (sym_link == 'cl-core' or sym_link == 'cl-core_py3'):
         for k, v in sorted(LoadedMethods.conMethods.items(),
                            key=lambda x: x[1]):
             name, user, title = v
             print("%s - %s" % (name, title))
         return 0
+    elif args.list_methods and not (sym_link == 'cl-core' or sym_link == 'cl-core_py3'):
+        print(_("--list \ --list-methods param is only used with cl-core comand"))
+        return 1
 
     colorPrint = color_print()
     # metaObject = metaclass()
