@@ -65,7 +65,7 @@ def get_ca(cert_path):
     Issuer = certobj.get_issuer().get_components()
     issuer_CN = None
     for item in Issuer:
-        if item[0] == 'CN':
+        if item[0] == b'CN':
             issuer_CN = item[1]
 
     if issuer_CN is None:
@@ -78,6 +78,6 @@ def get_ca(cert_path):
 
         Subject = certobj.get_subject().get_components()
         for subj in Subject:
-            if subj[0] == 'CN' and subj[1] == issuer_CN:
+            if subj[0] == b'CN' and subj[1] == issuer_CN:
                 return ca
     return '2'
