@@ -284,7 +284,12 @@ class VariableClCorePkgCategory(Variable):
             if type(category[0]) == dict:
                 category = ""
             else:
-                category = category[0].rpartition('/')[2]
+                if len(category) > 1:
+                    for x in category:
+                        if not "acct-user" in x and not "acct-group" in x and not "virtual" in x:
+                            category = x.rpartition('/')[2]
+                else:
+                    category = category[0].rpartition('/')[2]
         else:
             choice = self.choice()
             if len(choice) == 1:
